@@ -1,5 +1,6 @@
 mod first_line;
 mod second_line;
+mod tip;
 
 use ansi_term::Style;
 
@@ -11,6 +12,7 @@ use first_line::{ctrl_keys, superkey};
 use second_line::{
     fullscreen_panes_to_hide, keybinds, locked_fullscreen_panes_to_hide, text_copied_hint,
 };
+use tip::utils::get_cached_tip_name;
 
 // for more of these, copy paste from: https://en.wikipedia.org/wiki/Box-drawing_character
 static ARROW_SEPARATOR: &str = "";
@@ -19,6 +21,7 @@ static MORE_MSG: &str = " ... ";
 #[derive(Default)]
 struct State {
     tabs: Vec<TabInfo>,
+    tip_name: String,
     mode_info: ModeInfo,
     diplay_text_copied_hint: bool,
 }
@@ -131,6 +134,8 @@ fn color_elements(palette: Palette) -> ColoredElements {
 
 impl ZellijPlugin for State {
     fn load(&mut self) {
+        // TODO: Should be able to choose whether to use the cache through config.
+        self.tip_name = get_cached_tip_name();
         set_selectable(false);
         subscribe(&[
             EventType::ModeUpdate,
@@ -176,7 +181,7 @@ impl ZellijPlugin for State {
         let first_line = format!("{}{}", superkey, ctrl_keys);
 
         let mut second_line = LinePart::default();
-        for t in self.tabs.iter_mut() {
+        for t in &mut self.tabs {
             if t.active {
                 match self.mode_info.mode {
                     InputMode::Normal => {
@@ -190,7 +195,7 @@ impl ZellijPlugin for State {
                             second_line = if self.diplay_text_copied_hint {
                                 text_copied_hint(&self.mode_info.palette)
                             } else {
-                                keybinds(&self.mode_info, cols)
+                                keybinds(&self.mode_info, &self.tip_name, cols)
                             }
                         }
                     }
@@ -208,7 +213,7 @@ impl ZellijPlugin for State {
                             second_line = if self.diplay_text_copied_hint {
                                 text_copied_hint(&self.mode_info.palette)
                             } else {
-                                keybinds(&self.mode_info, cols)
+                                keybinds(&self.mode_info, &self.tip_name, cols)
                             }
                         }
                     }
@@ -216,7 +221,7 @@ impl ZellijPlugin for State {
                         second_line = if self.diplay_text_copied_hint {
                             text_copied_hint(&self.mode_info.palette)
                         } else {
-                            keybinds(&self.mode_info, cols)
+                            keybinds(&self.mode_info, &self.tip_name, cols)
                         }
                     }
                 }
