@@ -7,10 +7,13 @@ use std::{
     str,
 };
 
-use zellij_utils::{position::Position, vte, zellij_tile};
+use zellij_utils::{
+    consts::{DEFAULT_SCROLL_BUFFER_SIZE, SCROLL_BUFFER_SIZE},
+    position::Position,
+    vte, zellij_tile,
+};
 
 const TABSTOP_WIDTH: usize = 8; // TODO: is this always right?
-pub const SCROLL_BACK: usize = 10_000;
 pub const MAX_TITLE_STACK_SIZE: usize = 1000;
 
 use vte::{Params, Perform};
@@ -226,7 +229,7 @@ fn transfer_rows_from_lines_below_to_viewport(
 
 fn bounded_push(vec: &mut VecDeque<Row>, value: Row) -> Option<usize> {
     let mut dropped_line_width = None;
-    if vec.len() >= SCROLL_BACK {
+    if vec.len() >= *SCROLL_BUFFER_SIZE.get().unwrap() {
         let line = vec.pop_front();
         if let Some(line) = line {
             dropped_line_width = Some(line.width());
@@ -399,6 +402,7 @@ pub struct Grid {
     pub title: Option<String>,
     pub is_scrolled: bool,
     pub link_handler: LinkHandler,
+    pub ring_bell: bool,
     scrollback_buffer_lines: usize,
 }
 
@@ -418,7 +422,11 @@ impl Debug for Grid {
 impl Grid {
     pub fn new(rows: usize, columns: usize, colors: Palette) -> Self {
         Grid {
-            lines_above: VecDeque::with_capacity(SCROLL_BACK),
+            lines_above: VecDeque::with_capacity(
+                // .get_or_init() is used instead of .get().unwrap() to prevent
+                // unit tests from panicking where SCROLL_BUFFER_SIZE is uninitialized.
+                *SCROLL_BUFFER_SIZE.get_or_init(|| DEFAULT_SCROLL_BUFFER_SIZE),
+            ),
             viewport: vec![Row::new(columns).canonical()],
             lines_below: vec![],
             horizontal_tabstops: create_horizontal_tabstops(columns),
@@ -446,6 +454,7 @@ impl Grid {
             changed_colors: None,
             is_scrolled: false,
             link_handler: Default::default(),
+            ring_bell: false,
             scrollback_buffer_lines: 0,
         }
     }
@@ -1348,7 +1357,7 @@ impl Grid {
         self.should_render = true;
     }
     fn reset_terminal_state(&mut self) {
-        self.lines_above = VecDeque::with_capacity(SCROLL_BACK);
+        self.lines_above = VecDeque::with_capacity(*SCROLL_BUFFER_SIZE.get().unwrap());
         self.lines_below = vec![];
         self.viewport = vec![Row::new(self.width).canonical()];
         self.alternative_lines_above_viewport_and_cursor = None;
@@ -1506,6 +1515,9 @@ impl Perform for Grid {
 
     fn execute(&mut self, byte: u8) {
         match byte {
+            7 => {
+                self.ring_bell = true;
+            }
             8 => {
                 // backspace
                 self.move_cursor_back(1);
@@ -1844,7 +1856,7 @@ impl Perform for Grid {
                     Some(1049) => {
                         let current_lines_above = std::mem::replace(
                             &mut self.lines_above,
-                            VecDeque::with_capacity(SCROLL_BACK),
+                            VecDeque::with_capacity(*SCROLL_BUFFER_SIZE.get().unwrap()),
                         );
                         let current_viewport = std::mem::replace(
                             &mut self.viewport,
@@ -2249,14 +2261,16 @@ impl Row {
         }
     }
     pub fn insert_character_at(&mut self, terminal_character: TerminalCharacter, x: usize) {
-        match self.columns.len().cmp(&x) {
+        let insert_position = self.absolute_character_index(x);
+        match self.columns.len().cmp(&insert_position) {
             Ordering::Equal => self.columns.push_back(terminal_character),
             Ordering::Less => {
-                self.columns.resize(x, EMPTY_TERMINAL_CHARACTER);
+                self.columns
+                    .resize(insert_position, EMPTY_TERMINAL_CHARACTER);
                 self.columns.push_back(terminal_character);
             }
             Ordering::Greater => {
-                self.columns.insert(x, terminal_character);
+                self.columns.insert(insert_position, terminal_character);
             }
         }
     }
@@ -2365,8 +2379,9 @@ impl Row {
         self.columns.is_empty()
     }
     pub fn delete_and_return_character(&mut self, x: usize) -> Option<TerminalCharacter> {
-        if x < self.columns.len() {
-            Some(self.columns.remove(x).unwrap()) // TODO: just return the remove part?
+        let erase_position = self.absolute_character_index(x);
+        if erase_position < self.columns.len() {
+            Some(self.columns.remove(erase_position).unwrap()) // TODO: just return the remove part?
         } else {
             None
         }
