@@ -420,6 +420,42 @@ fn wide_characters_line_wrap() {
     assert_snapshot!(format!("{:?}", grid));
 }
 
+#[test]
+fn insert_character_in_line_with_wide_character() {
+    let mut vte_parser = vte::Parser::new();
+    let mut grid = Grid::new(21, 104, Palette::default());
+    let fixture_name = "wide_characters_middle_line_insert";
+    let content = read_fixture(fixture_name);
+    for byte in content {
+        vte_parser.advance(&mut grid, byte);
+    }
+    assert_snapshot!(format!("{:?}", grid));
+}
+
+#[test]
+fn delete_char_in_middle_of_line_with_widechar() {
+    let mut vte_parser = vte::Parser::new();
+    let mut grid = Grid::new(21, 104, Palette::default());
+    let fixture_name = "wide-chars-delete-middle";
+    let content = read_fixture(fixture_name);
+    for byte in content {
+        vte_parser.advance(&mut grid, byte);
+    }
+    assert_snapshot!(format!("{:?}", grid));
+}
+
+#[test]
+fn delete_char_in_middle_of_line_with_multiple_widechars() {
+    let mut vte_parser = vte::Parser::new();
+    let mut grid = Grid::new(21, 104, Palette::default());
+    let fixture_name = "wide-chars-delete-middle-after-multi";
+    let content = read_fixture(fixture_name);
+    for byte in content {
+        vte_parser.advance(&mut grid, byte);
+    }
+    assert_snapshot!(format!("{:?}", grid));
+}
+
 #[test]
 fn fish_wide_characters_override_clock() {
     let mut vte_parser = vte::Parser::new();
@@ -1022,3 +1058,35 @@ pub fn insert_wide_characters_in_existing_line() {
     }
     assert_snapshot!(format!("{:?}", grid));
 }
+
+#[test]
+pub fn full_screen_scroll_region_and_scroll_up() {
+    // this test is a regression test for a bug
+    // where the scroll region would be set to the
+    // full viewport and then scrolling up would cause
+    // lines to get deleted from the viewport rather
+    // than moving to "lines_above"
+    let mut vte_parser = vte::Parser::new();
+    let mut grid = Grid::new(54, 80, Palette::default());
+    let fixture_name = "scroll_region_full_screen";
+    let content = read_fixture(fixture_name);
+    for byte in content {
+        vte_parser.advance(&mut grid, byte);
+    }
+    grid.scroll_up_one_line();
+    grid.scroll_up_one_line();
+    grid.scroll_up_one_line();
+    assert_snapshot!(format!("{:?}", grid));
+}
+
+#[test]
+pub fn ring_bell() {
+    let mut vte_parser = vte::Parser::new();
+    let mut grid = Grid::new(134, 64, Palette::default());
+    let fixture_name = "ring_bell";
+    let content = read_fixture(fixture_name);
+    for byte in content {
+        vte_parser.advance(&mut grid, byte);
+    }
+    assert!(grid.ring_bell);
+}
