@@ -8,6 +8,7 @@ use std::fmt::Write;
 
 #[test]
 pub fn scrolling_inside_a_pane() {
+    let fake_client_id = 1;
     let mut fake_win_size = PaneGeom::default();
     fake_win_size.cols.set_inner(121);
     fake_win_size.rows.set_inner(20);
@@ -20,9 +21,9 @@ pub fn scrolling_inside_a_pane() {
         writeln!(&mut text_to_fill_pane, "\rline {}", i + 1).unwrap();
     }
     terminal_pane.handle_pty_bytes(text_to_fill_pane.into_bytes());
-    terminal_pane.scroll_up(10);
+    terminal_pane.scroll_up(10, fake_client_id);
     assert_snapshot!(format!("{:?}", terminal_pane.grid));
-    terminal_pane.scroll_down(3);
+    terminal_pane.scroll_down(3, fake_client_id);
     assert_snapshot!(format!("{:?}", terminal_pane.grid));
     terminal_pane.clear_scroll();
     assert_snapshot!(format!("{:?}", terminal_pane.grid));
