@@ -31,7 +31,11 @@ fn route_action(
     let mut should_break = false;
     session
         .senders
-        .send_to_plugin(PluginInstruction::Update(None, Event::InputReceived))
+        .send_to_plugin(PluginInstruction::Update(
+            None,
+            Some(client_id),
+            Event::InputReceived,
+        ))
         .unwrap();
     match action {
         Action::ToggleTab => {
@@ -55,7 +59,7 @@ fn route_action(
                 .senders
                 .send_to_screen(ScreenInstruction::ClearScroll(client_id))
                 .unwrap();
-            let val = Vec::from(val.as_bytes());
+            let val = val.into_bytes();
             session
                 .senders
                 .send_to_screen(ScreenInstruction::WriteCharacter(val, client_id))
@@ -70,6 +74,7 @@ fn route_action(
                 .senders
                 .send_to_plugin(PluginInstruction::Update(
                     None,
+                    Some(client_id),
                     Event::ModeUpdate(get_mode_info(mode, palette, session.capabilities)),
                 ))
                 .unwrap();
@@ -221,6 +226,12 @@ fn route_action(
             };
             session.senders.send_to_pty(pty_instr).unwrap();
         }
+        Action::PaneNameInput(c) => {
+            session
+                .senders
+                .send_to_screen(ScreenInstruction::UpdatePaneName(c, client_id))
+                .unwrap();
+        }
         Action::Run(command) => {
             let run_cmd = Some(TerminalAction::RunCommand(command.clone().into()));
             let pty_instr = match command.direction {
@@ -379,12 +390,8 @@ pub(crate) fn route_thread_main(
             ClientToServerMsg::Action(action) => {
                 if let Some(rlocked_sessions) = rlocked_sessions.as_ref() {
                     if let Action::SwitchToMode(input_mode) = action {
-                        for client_id in session_state.read().unwrap().clients.keys() {
-                            os_input.send_to_client(
-                                *client_id,
-                                ServerToClientMsg::SwitchToMode(input_mode),
-                            );
-                        }
+                        os_input
+                            .send_to_client(client_id, ServerToClientMsg::SwitchToMode(input_mode));
                     }
                     if route_action(action, rlocked_sessions, &*os_input, &to_server, client_id) {
                         break;
