@@ -3,6 +3,32 @@ use std::fmt;
 use std::str::FromStr;
 use strum_macros::{EnumDiscriminants, EnumIter, EnumString, ToString};
 
+pub type ClientId = u16; // TODO: merge with crate type?
+
+pub fn client_id_to_colors(
+    client_id: ClientId,
+    colors: Palette,
+) -> Option<(PaletteColor, PaletteColor)> {
+    // (primary color, secondary color)
+    match client_id {
+        1 => Some((colors.magenta, colors.black)),
+        2 => Some((colors.blue, colors.black)),
+        3 => Some((colors.purple, colors.black)),
+        4 => Some((colors.yellow, colors.black)),
+        5 => Some((colors.cyan, colors.black)),
+        6 => Some((colors.gold, colors.black)),
+        7 => Some((colors.red, colors.black)),
+        8 => Some((colors.silver, colors.black)),
+        9 => Some((colors.pink, colors.black)),
+        10 => Some((colors.brown, colors.black)),
+        _ => None,
+    }
+}
+
+pub fn single_client_color(colors: Palette) -> (PaletteColor, PaletteColor) {
+    (colors.green, colors.black)
+}
+
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
 pub enum Key {
     Backspace,
@@ -34,6 +60,7 @@ pub enum Mouse {
     ScrollUp(usize),                 // number of lines
     ScrollDown(usize),               // number of lines
     LeftClick(isize, usize),         // line and column
+    RightClick(isize, usize),        // line and column
     Hold(isize, usize),              // line and column
     Release(Option<(isize, usize)>), // line and column
 }
@@ -76,14 +103,21 @@ pub enum InputMode {
     /// `Scroll` mode allows scrolling up and down within a pane.
     #[serde(alias = "scroll")]
     Scroll,
+    /// `RenameTab` mode allows assigning a new name to a tab.
     #[serde(alias = "renametab")]
     RenameTab,
+    /// `RenamePane` mode allows assigning a new name to a pane.
+    #[serde(alias = "renamepane")]
+    RenamePane,
     /// `Session` mode allows detaching sessions
     #[serde(alias = "session")]
     Session,
     /// `Move` mode allows moving the different existing panes within a tab
     #[serde(alias = "move")]
     Move,
+    /// `Prompt` mode allows interacting with active prompts.
+    #[serde(alias = "prompt")]
+    Prompt,
 }
 
 impl Default for InputMode {
@@ -128,6 +162,8 @@ impl FromStr for InputMode {
             "renametab" => Ok(InputMode::RenameTab),
             "session" => Ok(InputMode::Session),
             "move" => Ok(InputMode::Move),
+            "prompt" => Ok(InputMode::Prompt),
+            "renamepane" => Ok(InputMode::RenamePane),
             e => Err(e.to_string().into()),
         }
     }
@@ -158,6 +194,12 @@ pub struct Palette {
     pub cyan: PaletteColor,
     pub white: PaletteColor,
     pub orange: PaletteColor,
+    pub gray: PaletteColor,
+    pub purple: PaletteColor,
+    pub gold: PaletteColor,
+    pub silver: PaletteColor,
+    pub pink: PaletteColor,
+    pub brown: PaletteColor,
 }
 
 /// Represents the contents of the help message that is printed in the status bar,
@@ -182,6 +224,7 @@ pub struct TabInfo {
     pub panes_to_hide: usize,
     pub is_fullscreen_active: bool,
     pub is_sync_panes_active: bool,
+    pub other_focused_clients: Vec<ClientId>,
 }
 
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Hash, Deserialize, Serialize)]
